from setuptools import setup

setup(
    name='newdiscord.py',
    version='0.0.1',
    description='new discord',
    long_description='',
    url='https://anonattack.cf/attack.php',
    author='のなめ',
    author_email='anonatkdiscord@gmail.com',
    packages=[""],
    classifiers=['Development Status :: 1 - Planning'],
)
